@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 """Top-level package for Python polarization."""
 
-__author__ = """Luis Miguel Sanchez Brea / Jesus del Hoyo Munoz"""
-__email__ = 'optbrea@ucm.es'
-__version__ = '1.0.2'
+__author__ = """Jesus del Hoyo Munoz / Luis Miguel Sanchez Brea"""
+__email__ = 'jhoyo@ucm.es'
+__version__ = '1.0.3'
 
 import numpy as np
 import scipy as sp
