@@ -173,7 +173,12 @@ def draw_empty_sphere(ax, angle_view, axis_equal=True):
     plt.tight_layout()
     # set_aspect_equal_3d(ax)
     if axis_equal:
-        ax.set_aspect('equal')
+        try:
+            ax.set_aspect('equal')
+        except:
+            print(
+                'Axis equal not supported by your current version of Matplotlib'
+            )
 
 
 def draw_poincare(S,
